@@ -1,6 +1,6 @@
 import "locale";
 
-d3.locale.pt_BR = d3.locale({
+var d3_locale_ptBR = d3.locale({
   decimal: ',',
   thousands: '.',
   grouping: [3],
