@@ -114,6 +114,12 @@ suite.addBatch({
         var x = ordinal().domain(["a", "b", "c"]).rangePoints([0, 120], 2);
         assert.deepEqual(x.range(), [30, 60, 90]);
       },
+      "correctly handles empty domains": function(ordinal) {
+        var x = ordinal().domain([]).rangePoints([0, 120]);
+        assert.deepEqual(x.range(), []);
+        assert.isUndefined(x("b"));
+        assert.deepEqual(x.domain(), []);
+      },
       "correctly handles singleton domains": function(ordinal) {
         var x = ordinal().domain(["a"]).rangePoints([0, 120]);
         assert.deepEqual(x.range(), [60]);
@@ -122,7 +128,7 @@ suite.addBatch({
       },
       "can be set to a descending range": function(ordinal) {
         var x = ordinal().domain(["a", "b", "c"]).rangePoints([120, 0]);
-        assert.deepEqual(x.range(), [120, 60,0]);
+        assert.deepEqual(x.range(), [120, 60, 0]);
         var x = ordinal().domain(["a", "b", "c"]).rangePoints([120, 0], 1);
         assert.deepEqual(x.range(), [100, 60, 20]);
         var x = ordinal().domain(["a", "b", "c"]).rangePoints([120, 0], 2);
@@ -157,12 +163,78 @@ suite.addBatch({
       }
     },
 
+    "rangeRoundPoints": {
+      "computes discrete points in a continuous range": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 120]);
+        assert.deepEqual(x.range(), [0, 60, 120]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 120], 1);
+        assert.deepEqual(x.range(), [20, 60, 100]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 120], 2);
+        assert.deepEqual(x.range(), [30, 60, 90]);
+      },
+      "rounds to the nearest equispaced integer values": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119]);
+        assert.deepEqual(x.range(), [1, 60, 119]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119], 1);
+        assert.deepEqual(x.range(), [21, 60, 99]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119], 2);
+        assert.deepEqual(x.range(), [31, 60, 89]);
+      },
+      "correctly handles empty domains": function(ordinal) {
+        var x = ordinal().domain([]).rangeRoundPoints([0, 119]);
+        assert.deepEqual(x.range(), []);
+        assert.isUndefined(x("b"));
+        assert.deepEqual(x.domain(), []);
+      },
+      "correctly handles singleton domains": function(ordinal) {
+        var x = ordinal().domain(["a"]).rangeRoundPoints([0, 119]);
+        assert.deepEqual(x.range(), [60]);
+        assert.isUndefined(x("b"));
+        assert.deepEqual(x.domain(), ["a"]);
+      },
+      "can be set to a descending range": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0]);
+        assert.deepEqual(x.range(), [119, 60, 1]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0], 1);
+        assert.deepEqual(x.range(), [99, 60, 21]);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0], 2);
+        assert.deepEqual(x.range(), [89, 60, 31]);
+      },
+      "has a rangeBand of zero": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119]);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119], 1);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 119], 2);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a"]).rangeRoundPoints([0, 119]);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0]);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0], 1);
+        assert.equal(x.rangeBand(), 0);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([119, 0], 2);
+        assert.equal(x.rangeBand(), 0);
+      },
+      "returns undefined for values outside the domain": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 1]);
+        assert.isUndefined(x("d"));
+        assert.isUndefined(x("e"));
+        assert.isUndefined(x("f"));
+      },
+      "does not implicitly add values to the domain": function(ordinal) {
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundPoints([0, 1]);
+        x("d"), x("e");
+        assert.deepEqual(x.domain(), ["a", "b", "c"]);
+      }
+    },
+
     "rangeBands": {
       "computes discrete bands in a continuous range": function(ordinal) {
         var x = ordinal().domain(["a", "b", "c"]).rangeBands([0, 120]);
         assert.deepEqual(x.range(), [0, 40, 80]);
         assert.equal(x.rangeBand(), 40);
-        var x = ordinal().domain(["a", "b", "c"]).rangeBands([0, 120], .2);
+        var x = ordinal().domain(["a", "b", "c"]).rangeBands([0, 120], 0.2);
         assert.deepEqual(x.range(), [7.5, 45, 82.5]);
         assert.equal(x.rangeBand(), 30);
       },
@@ -178,15 +250,15 @@ suite.addBatch({
         var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0]);
         assert.deepEqual(x.range(), [80, 40, 0]);
         assert.equal(x.rangeBand(), 40);
-        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], .2);
+        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], 0.2);
         assert.deepEqual(x.range(), [82.5, 45, 7.5]);
         assert.equal(x.rangeBand(), 30);
       },
       "can specify a different outer padding": function(ordinal) {
-        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], .2, .1);
+        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], 0.2, 0.1);
         assert.deepEqual(x.range(), [84, 44, 4]);
         assert.equal(x.rangeBand(), 32);
-        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], .2, 1);
+        var x = ordinal().domain(["a", "b", "c"]).rangeBands([120, 0], 0.2, 1);
         assert.deepEqual(x.range(), [75, 50, 25]);
         assert.equal(x.rangeBand(), 20);
       },
@@ -208,7 +280,7 @@ suite.addBatch({
         var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([0, 100]);
         assert.deepEqual(x.range(), [1, 34, 67]);
         assert.equal(x.rangeBand(), 33);
-        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([0, 100], .2);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([0, 100], 0.2);
         assert.deepEqual(x.range(), [7, 38, 69]);
         assert.equal(x.rangeBand(), 25);
       },
@@ -216,15 +288,15 @@ suite.addBatch({
         var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([100, 0]);
         assert.deepEqual(x.range(), [67, 34, 1]);
         assert.equal(x.rangeBand(), 33);
-        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([100, 0], .2);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([100, 0], 0.2);
         assert.deepEqual(x.range(), [69, 38, 7]);
         assert.equal(x.rangeBand(), 25);
       },
       "can specify a different outer padding": function(ordinal) {
-        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([120, 0], .2, .1);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([120, 0], 0.2, 0.1);
         assert.deepEqual(x.range(), [84, 44, 4]);
         assert.equal(x.rangeBand(), 32);
-        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([120, 0], .2, 1);
+        var x = ordinal().domain(["a", "b", "c"]).rangeRoundBands([120, 0], 0.2, 1);
         assert.deepEqual(x.range(), [75, 50, 25]);
         assert.equal(x.rangeBand(), 20);
       },
@@ -284,7 +356,7 @@ suite.addBatch({
         assert.deepEqual(y.range(), ["foo", "baz"]);
       },
       "changes to the range type are isolated": function(ordinal) {
-        var x = ordinal().domain([0, 1]).rangeBands([0, 1], .2), y = x.copy();
+        var x = ordinal().domain([0, 1]).rangeBands([0, 1], 0.2), y = x.copy();
         x.rangePoints([1, 2]);
         assert.inDelta(x(0), 1, 1e-6);
         assert.inDelta(x(1), 2, 1e-6);
